Compiler

Trait Compiler 

pub trait Compiler {
    // Required method
    fn compile(
        &self,
        kernel: &impl Kernel,
        target: &impl Target,
        force: bool,
    ) -> Result<String>;
}
Something capable of compiling a Kernel for a Target.

Required Methods

fn compile( &self, kernel: &impl Kernel, target: &impl Target, force: bool, ) -> Result<String>

Compiles kernel for target, returning the path to the compiled artifact. force recompiles even if a cached artifact exists.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors