sequential

Macro sequential 

macro_rules! sequential {
    ( $first:expr $(, $rest:expr )* ) => { ... };
}
Chains a sequence of Layers into a single closure, calling each in order and feeding each output into the next.