Softplus

Struct Softplus 

pub struct Softplus<D: Float, T, const RANK: usize> {
    pub beta: f64,
    pub threshold: f64,
    /* private fields */
}
Softplus activation layer: a smooth ReLU approximation, (1/beta) * ln(1 + e^(beta*x)), reverting to linear above threshold for numerical stability.

Fields

beta: f64

The beta sharpness parameter.

threshold: f64

Above this value, the layer reverts to linear (x) to avoid overflow in exp.

Implementations

Source

impl<D: Float, T, const RANK: usize> Softplus<D, T, RANK>

pub fn new(beta: f64, threshold: f64) -> Self

Creates a new Softplus layer with the given beta/threshold.