AvgPool2d

Struct AvgPool2d 

pub struct AvgPool2d<D: Dtype, IT, OT, const RANK: usize> {
    pub kernel_h: usize,
    pub kernel_w: usize,
    pub stride_h: usize,
    pub stride_w: usize,
    pub padding_h: usize,
    pub padding_w: usize,
    /* private fields */
}
2-D average pooling.

Fields

kernel_h: usize

Pooling window height.

kernel_w: usize

Pooling window width.

stride_h: usize

Vertical stride between pooling windows.

stride_w: usize

Horizontal stride between pooling windows.

padding_h: usize

Vertical padding applied before pooling.

padding_w: usize

Horizontal padding applied before pooling.

Implementations

Source

impl<D: Dtype, IT, OT, const RANK: usize> AvgPool2d<D, IT, OT, RANK>

pub fn new(kernel_size: (usize, usize), stride: (usize, usize)) -> Self

Creates a new layer with the given kernel size and stride, no padding.

pub fn with_padding( kernel_size: (usize, usize), stride: (usize, usize), padding: (usize, usize), ) -> Self

Creates a new layer with the given kernel size, stride, and padding.