Dag

Struct Dag 

pub struct Dag<V> { /* private fields */ }
A directed acyclic graph of V-valued nodes.

Implementations

Source

impl<V> Dag<V>

pub fn new() -> Self

Create an empty DAG.

pub fn add_node(&mut self, value: V) -> usize

Adds a node to the graph, returns index of the node.

pub fn add_edge(&mut self, from: usize, to: usize)

Adds a directed edge from from to to. Panics if indices are out of bounds or would cause a self-loop. Ignores duplicate edges.

pub fn node(&self, idx: usize) -> &Node<V>

Returns a reference to the node at the given index.

pub fn node_mut(&mut self, idx: usize) -> &mut Node<V>

Returns a mutable reference to the node at the given index.

pub fn len(&self) -> usize

Returns the number of nodes in the graph.

pub fn is_empty(&self) -> bool

Returns true if the graph contains no nodes.

pub fn topological_sort(&self) -> Vec<usize>

Perform a topological sort. Returns a list of node indices. Panics if the graph contains a cycle.