pub struct Flatten<D: Dtype, IT, OT> { /* private fields */ }Expand description
Flatten layer: collapses all spatial dimensions into a single feature vector.
Input shape: [N, C, H, W] (rank 4)
Output shape: [N, C * H * W] (rank 2)
Type parameters:
D— element dtypeIT— input tensor type (rank 4:[N, C, H, W])OT— output tensor type (rank 2:[N, C*H*W])
Tensor bounds are on impls, not the struct, so SymTensor can have its
own Layer impl without a coherence conflict.
Implementations